package net.sf.saxon.expr.parser;

import net.sf.saxon.expr.Container;
import net.sf.saxon.expr.Expression;
import net.sf.saxon.expr.StaticContext;
import net.sf.saxon.expr.flwor.Clause;
import net.sf.saxon.om.StructuredQName;

/**
 *  A code injector can be used to add code to the expression tree (for example, diagnostic tracing code)
 *  during the process of parsing and tree construction
 */
public interface CodeInjector {

     /**
     * If tracing, wrap an expression in a trace instruction
     *
     * @param exp         the expression to be wrapped
     * @param env         the static context
     * @param construct   integer constant identifying the kind of construct
     * @param qName       the name of the construct (if applicable)
     * @return a replacement for the original expression (or the original expression unchanged)
     */

    public Expression inject(Expression exp, StaticContext env, int construct, StructuredQName qName);


    /**
     * Insert a tracing clause into a FLWOR expression
     */

    public Clause injectClause(Clause target, StaticContext env, Container container);
}

//
// The contents of this file are subject to the Mozilla Public License Version 1.0 (the "License");
// you may not use this file except in compliance with the License. You may obtain a copy of the
// License at http://www.mozilla.org/MPL/
//
// Software distributed under the License is distributed on an "AS IS" basis,
// WITHOUT WARRANTY OF ANY KIND, either express or implied.
// See the License for the specific language governing rights and limitations under the License.
//
// The Original Code is: all this file
//
// The Initial Developer of the Original Code is Saxonica Limited.
// Portions created by ___ are Copyright (C) ___. All rights reserved.
//
// Contributor(s):
//